(define-module (clight)
  #:use-module (guix build-system cmake)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (gnu packages version-control)
  #:use-module (gnu packages admin)
  #:use-module (gnu packages statistics)
  #:use-module (gnu packages manipulation)
  #:use-module (gnu packages base))

(define-public clight
  (package
    (name "clight")
    (version "4.9")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://github.com/FedeDP/Clight.git")
             (commit version)))
       (file-name (git-file-name name version))))
    (build-system cmake-build-system)
    (native-inputs
     `(("pkg-config" ,pkg-config)
       ("gcc" ,gcc)
       ("libsystemd" ,libsystemd)
       ("libpopt" ,popt)
       ("gsl" ,gsl)
       ("libconfig" ,libconfig)
       ("libmodule" ,libmodule)
       ("cmake" ,cmake)
       ("bash-completion" ,bash-completion)
       ("fish" ,fish)
       ("systemd" ,systemd)))
    (inputs
     `(("bash-completion" ,bash-completion)
       ("fish" ,fish)))
    (arguments
     `(#:configure-flags
       `("-DCMAKE_INSTALL_PREFIX=/usr"
         "-DCMAKE_INSTALL_LIBDIR=lib"
         "-DCMAKE_BUILD_TYPE=Release")
       #:phases
            (modify-phases %standard-phases
              (add-before 'configure 'setup-env
                (lambda _
                  (setenv "CC" (which "gcc"))
                  (setenv "CXX" (which "g++"))
                  (setenv "LD" (which "ld"))
                  (setenv "AR" (which "ar"))
                  (setenv "RANLIB" (which "ranlib"))
                  (setenv "LDFLAGS" "-lgcc -lgcc_s -lc")
                  (setenv "CMAKE_SKIP_INSTALL_RPATH" "TRUE")
                  (setenv "CMAKE_SKIP_BUILD_RPATH" "TRUE")
                  (setenv "CMAKE_SKIP_RPATH" "TRUE"))))))
    (synopsis "Daemon that adjusts screen brightness according to your surroundings.")
    (description "...")
    (home-page "https://github.com/FedeDP/Clight")
    (license license:mit)))